import _JSXStyle from "next/dist/shared/lib/styled-jsx";
export default class {
    render() {
        return <div className={"jsx-1f6cef12199c3a8f"}>

        <p className={"jsx-1f6cef12199c3a8f"}>test</p>

        <_JSXStyle id={"1f6cef12199c3a8f"}>{'p.jsx-1f6cef12199c3a8f{content:"`"}'}</_JSXStyle>

      </div>;
    }
};
